@@ -3,11 +3,6 @@
 # This file is part of the COVID-surge application.
 # https://github/dpploy/covid-surge
 # Valmor F. de Almeida dealmeidavf@gmail.com
-'''
-US States COVID-19 surge period analysis.
-
-Expand on this later.
-'''
 
 from covid_surge import Surge
 
@@ -50,7 +45,7 @@ def main():
 
     for (sort_key,data) in fit_data:
         state = data[0]
-        param_vec = data[3]
+        #param_vec = data[3]
         key = us_surge.get_bin_id(sort_key,bins)
         if key in state_groups:
             state_groups[key].append(state)
