@@ -3,13 +3,7 @@
 # This file is part of the COVID-surge application.
 # https://github/dpploy/covid-surge
 # Valmor F. de Almeida dealmeidavf@gmail.com
-'''
-Global COVID-19 surge period analysis.
 
-Expand on this later.
-'''
-
-import numpy as np
 from asserts import assert_equal
 
 from covid_surge import Surge
@@ -51,7 +45,7 @@ def test_main():
 
     for (sort_key,data) in fit_data:
         country = data[0]
-        param_vec = data[3]
+        #param_vec = data[3]
         key = g_surge.get_bin_id(sort_key,bins)
         if key in country_groups:
             country_groups[key].append(country)
